@@ -7,7 +7,6 @@ from pyannote.database.util import load_rttm
 from pyannote.metrics.diarization import DiarizationErrorRate
 from rx.core import Observer
 from typing_extensions import Literal
-from traceback import print_exc
 
 
 class WindowClosedException(Exception):
@@ -24,8 +23,9 @@ def _extract_annotation(value: Union[Tuple, Annotation]) -> Annotation:
 
 
 class RTTMWriter(Observer):
-    def __init__(self, path: Union[Path, Text], patch_collar: float = 0.05):
+    def __init__(self, uri: Text, path: Union[Path, Text], patch_collar: float = 0.05):
         super().__init__()
+        self.uri = uri
         self.patch_collar = patch_collar
         self.path = Path(path).expanduser()
         if self.path.exists():
@@ -35,25 +35,28 @@ class RTTMWriter(Observer):
         """Stitch same-speaker turns that are close to each other"""
         annotations = list(load_rttm(self.path).values())
         if annotations:
+            annotation = annotations[0]
+            annotation.uri = self.uri
             with open(self.path, 'w') as file:
-                annotations[0].support(self.patch_collar).write_rttm(file)
+                annotation.support(self.patch_collar).write_rttm(file)
 
     def on_next(self, value: Union[Tuple, Annotation]):
         annotation = _extract_annotation(value)
+        annotation.uri = self.uri
         with open(self.path, 'a') as file:
             annotation.write_rttm(file)
 
     def on_error(self, error: Exception):
         self.patch()
-        print_exc()
 
     def on_completed(self):
         self.patch()
 
 
 class DiarizationPredictionAccumulator(Observer):
-    def __init__(self, patch_collar: float = 0.05):
+    def __init__(self, uri: Optional[Text] = None, patch_collar: float = 0.05):
         super().__init__()
+        self.uri = uri
         self.patch_collar = patch_collar
         self._annotation = None
 
@@ -69,6 +72,7 @@ class DiarizationPredictionAccumulator(Observer):
 
     def on_next(self, value: Union[Tuple, Annotation]):
         annotation = _extract_annotation(value)
+        annotation.uri = self.uri
         if self._annotation is None:
             self._annotation = annotation
         else:
@@ -76,7 +80,6 @@ class DiarizationPredictionAccumulator(Observer):
 
     def on_error(self, error: Exception):
         self.patch()
-        print_exc()
 
     def on_completed(self):
         self.patch()
@@ -99,6 +102,7 @@ class RealTimePlot(Observer):
         self.window_duration = duration
         self.latency = latency
         self.figure, self.axs, self.num_axs = None, None, -1
+        # This flag allows to catch the matplotlib window closed event and make the next call stop iterating
         self.window_closed = False
 
     def _on_window_closed(self, event):
@@ -159,7 +163,3 @@ class RealTimePlot(Observer):
         self.figure.canvas.draw()
         self.figure.canvas.flush_events()
         plt.pause(0.05)
-
-    def on_error(self, error: Exception):
-        if not isinstance(error, WindowClosedException):
-            print_exc()
